@@ -94,9 +94,17 @@ class RestApi(object):
         """ Dynamically add new fields to an existing serializer """
         # TODO provide support for hooking with nested serializers
         if model in self._registry:
-            self._registry[model][0].serializer_class.base_fields.update({name: field(**kwargs)})
-            self._registry[model][1].serializer_class.base_fields.update({name: field(**kwargs)})
-    
+            model_serializers = []
+            for api_view in self._registry[model]:
+                model_serializers.append(api_view.serializer_class)
+                # include serializers used on object creation
+                if getattr(api_view, 'add_serializer_class', None):
+                    model_serializers.append(api_view.add_serializer_class)
+            
+            # hook new attribute to each serializer
+            for serializer in model_serializers:
+                serializer.base_fields.update({name: field(**kwargs)})
+
 
 # singleton
 api = RestApi()
