@@ -2,12 +2,14 @@ from __future__ import absolute_import
 
 from permissions import Permission, ReadOnlyPermission, AllowAllPermission
 
-from .models import TincClient, TincServer, Host, Gateway, Island, TincAddress
+from .models import TincClient, TincServer, Host, Gateway, TincAddress
 
 
 class HostPermission(Permission):
     def view(self, obj, cls, user):
-        return True
+        if obj is None:
+            return True
+        return obj.owner == user
     
     def add(self, obj, cls, user):
         return True
@@ -29,5 +31,4 @@ TincClient.has_permission = AllowAllPermission()
 TincServer.has_permission = ReadOnlyPermission()
 Host.has_permission = HostPermission()
 Gateway.has_permission = ReadOnlyPermission()
-Island.has_permission = ReadOnlyPermission()
 TincAddress.has_permission = ReadOnlyPermission()
