@@ -97,7 +97,7 @@ class NodeAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmin
     display_cert.help_text = get_help_text(Node, 'cert')
     
     def num_ifaces(self, node):
-        """ Diplay number of direct ifaces, used on changelist """
+        """ Display number of direct ifaces, used on changelist """
         return node.direct_ifaces.count()
     num_ifaces.short_description = 'Ifaces'
     num_ifaces.admin_order_field = 'direct_ifaces__count'
@@ -112,9 +112,9 @@ class NodeAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmin
         form = super(NodeAdmin, self).get_form(request, obj=obj, *args, **kwargs)
         if 'group' in form.base_fields:
             # ronly forms doesn't have initial nor queryset
-            is_admin = Q(users__roles__is_admin=True)
-            is_technician = Q(users__roles__is_technician=True)
-            query = Q( is_admin | is_technician )
+            is_group_admin = Q(users__roles__is_group_admin=True)
+            is_node_admin = Q(users__roles__is_node_admin=True)
+            query = Q( is_group_admin | is_node_admin )
             query = Q( query & Q(allow_nodes=True) )
             form = filter_group_queryset(form, obj, request.user, query)
         if (obj is not None and obj.set_state == obj.FAILURE and
@@ -126,9 +126,15 @@ class NodeAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmin
         return form
     
     def queryset(self, request):
-        """ Annotate direct iface counter to allow ordering on change list """
+        """
+        Annotate direct iface and slivers counter to allow ordering
+        on change list. Intercept search query to allow search nodes
+        by management network IP
+        """
         qs = super(NodeAdmin, self).queryset(request)
         qs = qs.annotate(models.Count('direct_ifaces', distinct=True))
+        # FIXME: try to move to slices to avoid coupling nodes with slices app
+        qs = qs.annotate(models.Count('slivers', distinct=True))
         # HACK for searching nodes by IP
         search = request.GET.get('q', False)
         if search:
