@@ -170,7 +170,7 @@ class Migration(SchemaMigration):
         u'slices.slice': {
             'Meta': {'object_name': 'Slice'},
             'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
-            'exp_data': ('private_files.models.fields.PrivateFileField', [], {'max_length': '100', 'blank': 'True'}),
+            'exp_data': ('privatefiles.models.fields.PrivateFileField', [], {'max_length': '100', 'blank': 'True'}),
             'expires_on': ('django.db.models.fields.DateField', [], {'default': 'datetime.datetime(2013, 2, 7, 0, 0)', 'null': 'True', 'blank': 'True'}),
             'group': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['users.Group']"}),
             u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
@@ -191,7 +191,7 @@ class Migration(SchemaMigration):
         u'slices.sliver': {
             'Meta': {'unique_together': "(('slice', 'node'),)", 'object_name': 'Sliver'},
             'description': ('django.db.models.fields.CharField', [], {'max_length': '256', 'blank': 'True'}),
-            'exp_data': ('private_files.models.fields.PrivateFileField', [], {'max_length': '100', 'blank': 'True'}),
+            'exp_data': ('privatefiles.models.fields.PrivateFileField', [], {'max_length': '100', 'blank': 'True'}),
             u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'instance_sn': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0', 'blank': 'True'}),
             'node': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['nodes.Node']"}),
