@@ -43,7 +43,7 @@ class State(models.Model):
         ('registered', 'REGISTERED'),
         ('fail_start', 'FAIL_START'),
         ('fail_deploy', 'FAIL_DEPLOY'),
-        ('fail_alloc', 'FAIL_ALLOC'),
+        ('fail_allocate', 'FAIL_ALLOCATE'),
     )
     STATES = tuple(set(BASE_STATES+NODE_STATES+SLIVER_STATES))
     
@@ -68,6 +68,12 @@ class State(models.Model):
     def __unicode__(self):
         return self.value
     
+    def save(self, *args, **kwargs):
+        # backwards compatibility (#385)
+        if self.value == 'fail_alloc':
+            self.value = 'fail_allocate'
+        super(State, self).save(*args, **kwargs)
+    
     @property
     @cached
     def last_change_on(self):
