@@ -10,6 +10,11 @@ from .models import AuthToken, User, Group, Roles
 class GroupRolesSerializer(serializers.ModelSerializer):
     group = serializers.RelHyperlinkedRelatedField(view_name='group-detail')
     
+    # Backwards compatibilty #414
+    is_admin = serializers.Field(source='is_group_admin')
+    is_technician = serializers.Field(source='is_node_admin')
+    is_researcher = serializers.Field(source='is_slice_admin')
+    
     class Meta:
         model = Roles
         exclude = ['id', 'user']
@@ -25,6 +30,11 @@ class GroupRolesSerializer(serializers.ModelSerializer):
 class UserRolesSerializer(serializers.ModelSerializer):
     user = serializers.RelHyperlinkedRelatedField(view_name='user-detail')
     
+    # Backwards compatibilty #414
+    is_admin = serializers.Field(source='is_group_admin')
+    is_technician = serializers.Field(source='is_node_admin')
+    is_researcher = serializers.Field(source='is_slice_admin')
+    
     class Meta:
         model = Roles
         exclude = ['id', 'group']
@@ -99,7 +109,7 @@ class GroupSerializer(GroupCreateSerializer, serializers.DynamicReadonlyFieldsMo
     def validate_user_roles(self, attrs, name):
         """ checks at least one admin per group """
         for role in attrs.get(name, []):
-            if role.is_admin:
+            if role.is_group_admin:
                 return attrs
         raise ValidationError('The group must have at least one admin')
 
